//      Copyright UnacceptableUse, teknogeek 2014
//      For BaconGameJam-08. A game made in 48 hours.
//      Theme is 'Millions Of Them'

var game = new Phaser.Game(800, 600, Phaser.AUTO, '', { preload: preload, create: create, update: update, render: render });

function preload()
{
    game.load.spritesheet('sperm', 'assets/sperm.png', 64, 20);
    game.load.spritesheet('enemies', 'assets/enemies.png', 64,64);
    game.load.spritesheet('powerup', 'assets/powerup.png', 32, 32);
    game.load.image('gameover', 'assets/gameover.png');
    //game.load.image('egg', 'assets/egg.png');
}

var graphics, i, loadingText,scoreText;
var sperm, powerUp, powerUpTime = 0, topWallSprite, bottomWallSprite, score = 0, currentPowerUp = 0;
var enemies, end;
var hasDrawnUterus = false;
var isGameOver = false;
var keys;

function create()
{
    isGameOver = false;
    hasDrawnUterus = false;
    
    //WALLS
    topWallSprite = game.add.group();
    bottomWallSprite = game.add.group();
    
    // keep the spacebar from propogating up to the browser
    game.input.keyboard.addKeyCapture([Phaser.Keyboard.SPACEBAR]);

    // add keyboard controls
    var keys = this.input.keyboard.addKey(Phaser.Keyboard.SPACEBAR);
    keys.onDown.add(restartGame);
    
    enemies = game.add.group();
    
    //GRAPHICS
    loadingText = game.add.text(100, 100, "Loading...", { font: "24px Arial", fill: "#ffffff"});
    scoreText = game.add.text(10, 10, "0mm", { font: "24px Arial", fill: "#ffffff"});
    game.world.setBounds(0, 0, 9500, 600);
    game.time.advancedTiming = true;
    game.stage.backgroundColor = '#a43333';
    graphics = game.add.graphics(0, 0);
    
    //ENTITIES
    sperm = game.add.sprite(50, 300, 'sperm');
    sperm.animations.add('swim');
    
    
    sperm.animations.play('swim', 15, true);
    
    
    powerUp = game.add.sprite(0, 0, 'powerup');
    powerUp.outOfBoundsKill = true;
    powerUp.animations.add('pwrup');
    
    powerUp.animations.play('pwrup', 2150, true);
    
    powerUp.kill();
    
    //PHYSICS
    game.physics.startSystem(Phaser.Physics.ARCADE);
    game.physics.enable(sperm, Phaser.Physics.ARCADE);
    game.physics.enable(powerUp, Phaser.Physics.ARCADE);
    
    sperm.body.gravity.y = 350;
    sperm.body.collideWorldBounds = true;
    
    game.camera.follow(sperm);
}

function restartGame()
{
    if(isGameOver)
    {
        document.location.reload(true);
    }
}

function update()
{
    score = game.camera.x;
    if(score == 8700)
    {
        game.world.removeAll();
        game.add.text(game.camera.x,0, "Congratulations. You win!\nPat yourself on the back.\nMade in 48 hours for BaconGameJam 08 \nby UnacceptableUse and Teknogeek.\n\nThanks for playing!", { font: "24px Arial", fill: "#ffffff"});
        score = 0;
    }
    if(powerUpTime > 0)
    {
        powerUpTime--;
        if(currentPowerUp == 1)
        {
            sperm.scale.x = 0.5;
            sperm.scale.y = 0.5; 
        }
        
        if(currentPowerUp == 3)
        {
            sperm.body.gravity.y = 150;
        }
    }
    else
    {
        if(currentPowerUp == 1)
        {
            sperm.scale.x = 1;
            sperm.scale.y = 1; 
        }
        
        if(currentPowerUp == 3)
        {
            sperm.body.gravity.y = 350;
        }

        currentPowerUp = 0;
    }
    
    if(game.input.mouse.button === 0)
    {
        sperm.body.velocity.y = ((Math.floor((Math.random() * 1.25) + 5) * 100) / 100) * -30;
        sperm.body.velocity.x = currentPowerUp === 3 ? 100 : currentPowerUp == 2 ? 400  : 200;
    }
    
    if(sperm.body.velocity.y < 0)
    {
        if(sperm.angle > -5)
        {
            sperm.angle -= 0.5;
        }
    }
    else if(sperm.body.velocity.y > 0)
    {
        if(sperm.angle < 5)
        {
            sperm.angle += 0.5;
        }
    }
    
    doEnemies();
    game.physics.arcade.overlap(topWallSprite, sperm, function(collide)
    {
        topWallSprite.forEach(function(sprite)
        {
            var collisionCircle = new Phaser.Circle(sprite.x, sprite.y, 360);
            if(Phaser.Circle.intersectsRectangle(collisionCircle, sperm.body))
            {
                gameOver();
            }
        });
    });
    
    game.physics.arcade.overlap(bottomWallSprite, sperm, function(collide)
    {
        bottomWallSprite.forEach(function(sprite)
        {
            var collisionCircle = new Phaser.Circle(sprite.x, sprite.y - 180, 360);
            if(Phaser.Circle.intersectsRectangle(collisionCircle, sperm.body))
            {
                gameOver();
            }
        });
    });
    game.physics.arcade.collide(sperm, enemies, gameOver);
    game.physics.arcade.overlap(powerUp, sperm, getPowerUp);
}

function render()
{
    // game.debug.cameraInfo(game.camera, 500, 32);
    // game.debug.spriteCoords(sperm, 32, 32);
    
    if(currentPowerUp != 0)
    {
        scoreText.text = score + "mm | Powerup: "+ (currentPowerUp == 1 ? "MicroSperm" : currentPowerUp == 2 ? "Super Speed" : currentPowerUp == 3 ? "Slow Motion" : currentPowerUp == 4 ? "Invincibility" : "Unknown......wat") + " "+Math.floor(powerUpTime/60);
    }
    else
    {
            scoreText.text = score + "mm";
    }
    scoreText.x = game.camera.x;
    scoreText.y = game.camera.y;
    
    if(!hasDrawnUterus)
    {
        for(i = 0; i < 41; i++)
        {
            drawUterus(i);
        }
        hasDrawnUterus = true;
        
        game.physics.arcade.enable(bottomWallSprite);
        game.physics.arcade.enable(topWallSprite);
        
        topWallSprite.forEach(function(sprite)
        {
            sprite.body.allowGravity = false;
            sprite.body.immovable = true;
        });
        
        bottomWallSprite.forEach(function(sprite)
        {
            sprite.body.allowGravity = false;
            sprite.body.immovable = true;
        });
        loadingText.destroy();
    }
    
}

function drawUterus(i)
{
    var ySeed = ((Math.floor((Math.random() * 50) * 100)) / 100);
    
    //top uterus wall
    var topWall = game.add.bitmapData(4700, (ySeed + 180));

    topWall.clear();
    topWall.circle((i * 125), ySeed, 180, 'rgba(249, 102, 102, 1)');

    var topSprite = game.add.sprite((i * 125), 0, topWall);
    topWallSprite.add(topSprite);



    //bottom uterus wall
    var bottomWall = game.add.bitmapData(4700, (ySeed + 180));
    
    bottomWall.clear();
    bottomWall.circle((i * 125), (180 + ySeed), 180, 'rgba(249, 102, 102, 1)');
    
    var bottomSprite = game.add.sprite((i * 125), 475, bottomWall);
    
    bottomWallSprite.add(bottomSprite);
}


function doEnemies()
{
    if(game.rnd.integerInRange(1,100-(game.camera.x/100)) == 10)
    {
 
        var enemy = enemies.create(sperm.body.x + game.rnd.integerInRange(300, 550), sperm.body.y, 'enemies', 1); 
       // enemy.rotation = game.rnd.integerInRange(0, 360);
        game.physics.enable(enemy, Phaser.Physics.ARCADE);

        // var tween = game.add.tween(enemy); 
        // tween.to({ x: sperm.body.x+game.rnd.integerInRange(0,550), y: sperm.body.y }, 1000);
        // tween.start();
    }
    else if(game.rnd.integerInRange(1,100) == 10 && !powerUp.alive && currentPowerUp == 0)
    {
        
         powerUp.revive();
         powerUp.x = sperm.body.x+200;
         powerUp.y = sperm.body.y;
    }
}


function getPowerUp()
{
    powerUp.kill();
    powerUpTime = 500;
    currentPowerUp = game.rnd.integerInRange(1, 4);
}



function gameOver()
{
    if(currentPowerUp == 4)return;
    game.world.removeAll();
    game.add.text(game.camera.x + 300,game.camera.y + 400, "You swam " + score + "mm", { font: "24px Arial", fill: "#ffffff"});
    game.add.sprite(game.camera.x, 0, 'gameover');
    isGameOver = true;
}

